# Pydra2App

[![Tests](https://github.com/ArcanaFramework/pydra2app/actions/workflows/ci-cd.yml/badge.svg)](https://github.com/ArcanaFramework/pydra2app/actions/workflows/ci-cd.yml)
[![Codecov](https://codecov.io/gh/ArcanaFramework/pydra2app/branch/main/graph/badge.svg?token=UIS0OGPST7)](https://codecov.io/gh/ArcanaFramework/pydra2app)
[![Python versions](https://img.shields.io/pypi/pyversions/pydra2app.svg)](https://pypi.python.org/pypi/pydra2app/)
[![Latest Version](https://img.shields.io/pypi/v/pydra2app.svg)](https://pypi.python.org/pypi/pydra2app/)
[![Docs](https://img.shields.io/badge/docs-latest-brightgreen.svg?style=flat)](https://pydra2appframework.github.io/pydra2app)

Pydra2App is a tool for quickly turning Pydra tasks and workflows into containerised
applications (e.g. BIDS Apps or XNAT pipelines)

## Documentation

Detailed documentation on Arcana can be found at [https://pydra2app.readthedocs.io](https://pydra2app.readthedocs.io)


## Quick Installation

Pydra2App can be installed for Python 3 using *pip*:

```bash
$ python3 -m pip install pydra2app
```

## License

This work is licensed under a
[Creative Commons Attribution-NonCommercial-ShareAlike 4.0 International License](http://creativecommons.org/licenses/by-nc-sa/4.0/)

[![Creative Commons License: Attribution-NonCommercial-ShareAlike 4.0 International](https://i.creativecommons.org/l/by-nc-sa/4.0/88x31.png)](http://creativecommons.org/licenses/by-nc-sa/4.0/)


## Acknowledgements

The authors acknowledge the facilities and scientific and technical assistance of the National Imaging Facility, a National Collaborative Research Infrastructure Strategy (NCRIS) capability.

[Arcana]: http://pydra2app.readthedocs.io
[Pydra]: http://pydra.readthedocs.io
[XNAT]: http://xnat.org
[BIDS]: http://bids.neuroimaging.io/
[`Environment Modules`]: http://modules.sourceforge.net
